aboutsummaryrefslogtreecommitdiffhomepage
path: root/Eigen/src/plugins
diff options
context:
space:
mode:
authorGravatar Rasmus Munk Larsen <rmlarsen@google.com>2018-08-13 11:14:50 -0700
committerGravatar Rasmus Munk Larsen <rmlarsen@google.com>2018-08-13 11:14:50 -0700
commitd6e283ba9650faed0c48c36f475d5dd77b916427 (patch)
treef41d26e36f1fd7806ee53ed5e51995d4611d8b3a /Eigen/src/plugins
parentfa68342ef80d72f52b340851a5ab18003259b2ed (diff)
sigmoid -> logistic
Diffstat (limited to 'Eigen/src/plugins')
-rw-r--r--Eigen/src/plugins/ArrayCwiseUnaryOps.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/Eigen/src/plugins/ArrayCwiseUnaryOps.h b/Eigen/src/plugins/ArrayCwiseUnaryOps.h
index c9c7e7e4f..e928db467 100644
--- a/Eigen/src/plugins/ArrayCwiseUnaryOps.h
+++ b/Eigen/src/plugins/ArrayCwiseUnaryOps.h
@@ -21,7 +21,7 @@ typedef CwiseUnaryOp<internal::scalar_acos_op<Scalar>, const Derived> AcosReturn
typedef CwiseUnaryOp<internal::scalar_asin_op<Scalar>, const Derived> AsinReturnType;
typedef CwiseUnaryOp<internal::scalar_atan_op<Scalar>, const Derived> AtanReturnType;
typedef CwiseUnaryOp<internal::scalar_tanh_op<Scalar>, const Derived> TanhReturnType;
-typedef CwiseUnaryOp<internal::scalar_sigmoid_op<Scalar>, const Derived> SigmoidReturnType;
+typedef CwiseUnaryOp<internal::scalar_logistic_op<Scalar>, const Derived> LogisticReturnType;
typedef CwiseUnaryOp<internal::scalar_sinh_op<Scalar>, const Derived> SinhReturnType;
typedef CwiseUnaryOp<internal::scalar_cosh_op<Scalar>, const Derived> CoshReturnType;
typedef CwiseUnaryOp<internal::scalar_square_op<Scalar>, const Derived> SquareReturnType;
@@ -336,13 +336,13 @@ cosh() const
return CoshReturnType(derived());
}
/** \returns an expression of the coefficient-wise sigmoid of *this.
*/
EIGEN_DEVICE_FUNC
-inline const SigmoidReturnType
-sigmoid() const
+inline const LogisticReturnType
+logistic() const
{
- return SigmoidReturnType(derived());
+ return LogisticReturnType(derived());
}
/** \returns an expression of the coefficient-wise inverse of *this.
@@ -336,13 +336,13 @@ cosh() const
return CoshReturnType(derived());
}
-/** \returns an expression of the coefficient-wise sigmoid of *this.
+/** \returns an expression of the coefficient-wise logistic of *this.
*/
EIGEN_DEVICE_FUNC